const transferMode = {
  SAME: "SAME_BANK",
  OTHERS: "OTHER_BANK",
  INTERNATIONAL: "INTERNATIONAL",
};

Object.freeze(transferMode);

let countryError = document.getElementById('country_error');
let accountNumberError = document.getElementById('account_number_error');

window.addEventListener('DOMContentLoaded', (event) => {

  let country = document.getElementById('beneficiary_country');
  let flagImg = document.getElementById('flag_img');
  let countryAppend = document.getElementById('country_append');

  country.onchange = function (event) {
    countryError.innerHTML = '';
    if (!event.target.value) {
      flagImg.src = '';
      countryAppend.setAttribute('hidden', true)
      return;
    }

    let flag = $(this).find(':selected').data('flag');
    countryAppend.removeAttribute('hidden');
    flagImg.src = flag;

  }

});


$('#transfer_mode').select2({
  theme: 'bootstrap4',
  data: [
    {
      id: 'SAME_BANK',
      text: 'SAME BANK',
    },
    {
      id: 'OTHER_BANK',
      text: 'OTHER BANK',
    },
    {
      id: 'INTERNATIONAL',
      text: 'INTERNATIONAL',
    }]
});


$('#add_beneficiary_button').on('click', () => {
  $('#beneficiary_modal').modal().on('hidden.bs.modal', function () {


    let beneficiariesFormData = new FormData(beneficiaryForm);

    for (let formKey of beneficiariesFormData.keys()) {
      document.getElementById(formKey).classList.remove('is-invalid');
      $('#account_number_error, #country_error').html(null);

      if (formKey === 'transfer_mode') {
        $(`#${ formKey }`).val(transferMode.SAME).trigger('change');
        continue;
      }

      $(`#${ formKey }`).val(null).trigger('change');

      $('#receiver_name').val(null);
    }


  });
});

let beneficiaryForm = document.getElementById('beneficiary_form');

let currentMode = transferMode.SAME;

$('#transfer_mode').on('change', (e) => {

  let beneficiariesFormData = new FormData(beneficiaryForm);
  let excludeArray = [];

  currentMode = e.target.value;
  for (let formKey of beneficiariesFormData.keys()) {

    document.getElementById(formKey).classList.remove('is-invalid');

    switch (currentMode) {
      case transferMode.SAME:
        excludeArray = ['transfer_mode', 'receiver_account_number'];
        if (excludeArray.includes(formKey)) {
          $(`#${ formKey }`).parent().parent().removeAttr('hidden');
          continue;
        }

        if (formKey === 'beneficiary_country') {
          $(`#${ formKey }`).val(null).trigger('change').parent().parent().parent().attr('hidden', 'true');
          continue;
        }

        $('#account_number_error').html(null);
        $('#receiver_name').attr('disabled', 'true').parent().parent().removeAttr('hidden').removeClass('is-invalid');
        $(`#${ formKey }`).val(null).parent().parent().attr('hidden', 'true');

        break;
      case transferMode.OTHERS:
        excludeArray = ['transfer_mode', 'receiver_account_number', 'receiver_name', 'receiving_bank'];
        if (excludeArray.includes(formKey)) {
          $(`#${ formKey }`).parent().parent().removeAttr('hidden');
          continue;
        }

        if (formKey === 'beneficiary_country') {
          $(`#${ formKey }`).val(null).trigger('change').parent().parent().parent().attr('hidden', 'true');
          continue;
        }

        $(`#${ formKey }`).val(null).parent().parent().attr('hidden', 'true');

        $('#receiver_name').val(null).removeAttr('disabled').removeClass('is-invalid');
        $('#receiver_account_number').val(null).removeClass('is-invalid');
        $('#account_number_error').html(null);
        $('#save_beneficiary_button').removeAttr('disabled');

        break;
      case transferMode.INTERNATIONAL:

        if (formKey === 'beneficiary_country') {
          $(`#${ formKey }`).val(null).trigger('change').parent().parent().parent().removeAttr('hidden');
          continue;
        }

        $('#receiver_name').val(null).removeAttr('disabled').removeClass('is-invalid');

        $(`#${ formKey }`).parent().parent().removeAttr('hidden');

        $('#receiver_account_number').val(null).removeClass('is-invalid');
        $('#account_number_error').html(null);

        $('#save_beneficiary_button').removeAttr('disabled');
        break;

      default:
        break;
    }
  };

})

function fetchAccount() {

  $('#account_append').removeAttr('hidden');
  $('#save_beneficiary_button').attr('disabled', 'true');

  let receiverAccountNumber = $('#receiver_account_number').val();


  let checkAccountUrl = `${ URL_ROOT }/apps/check-same-bank-account?account_number=`;

  getData(checkAccountUrl + receiverAccountNumber).then(response => {

    $('#account_append').attr('hidden', true);

    if (response === false) {
      $('#receiver_name').val(null);
      $('#receiver_account_number').addClass('is-invalid');
      $('#account_number_error').html('Invalid beneficiary account number');
    } else {
      $('#receiver_name').val(response.full_name);
      $('#receiver_account_number').removeClass('is-invalid');
      $('#receiver_name').removeClass('is-invalid');
      $('#account_number_error').html(null);
      $('#save_beneficiary_button').removeAttr('disabled');
    }
  })

}

let debounceFetchAccount = debounce(function () {
  fetchAccount()
}, 500);

$('#receiver_account_number').on('keyup', (e) => {
  $('#receiver_account_number').removeClass('is-invalid');
  $('#account_number_error').html(null);

  if (currentMode !== transferMode.SAME) {
    return;
  }
  debounceFetchAccount();
});


let saveBeneficiaryButton = document.getElementById('save_beneficiary_button');

saveBeneficiaryButton.onclick = (e) => {

  let l = Ladda.create(saveBeneficiaryButton);
  l.start();

  let beneficiaryFormData = new FormData(beneficiaryForm);

  let dataToSubmit = {};

  for (let data of beneficiaryFormData.entries()) {
    dataToSubmit[data[0]] = data[1].toUpperCase();
  }


  if (currentMode === transferMode.SAME) {
    dataToSubmit.receiver_name = $('#receiver_name').val();
  }

  let beneficiaryUrl = `${ URL_ROOT }/apps/save-beneficiary`;

  $.ajax({
    url: beneficiaryUrl,
    type: 'POST',
    data: dataToSubmit,

     success: function (response) {

switch (response) {
      case false:
        l.stop()
        showToast('error', 'Unable to add beneficiary');
        break;

      case 'exists':
      
        showToast('warning', 'Beneficiary already exists.');
        setTimeout(() => {
          location.href = `${ URL_ROOT }/dashboard/beneficiaries`;
        }, 2000);
        break;

      case 'successful':
      l.stop();
     
        showToast('success', 'Beneficiary added successfully');
        setTimeout(() => {
          location.href = `${ URL_ROOT }/dashboard/beneficiaries`;
        }, 2000);
        break;

      default:
        l.stop();
        
        break;
    }


      
     }
    });
  

  
}



function deleteBeneficiary(beneficiaryId) {


  Swal.fire({
    title: 'Confirm Delete?',
    text: 'Are you sure you want to delete this beneficiary?',
    showCancelButton: true,
    confirmButtonText: 'Delete',
    buttonsStyling: false,
    allowOutsideClick: false,
    backdrop: true,
    reverseButtons: true,
    customClass: {
      confirmButton: 'btn btn-danger btn-sm ml-2',
      cancelButton: 'btn btn-default btn-sm mr-2',
    },
    showLoaderOnConfirm: true,
    preConfirm: () => {
      return deleteBeneficiaryApi(beneficiaryId);
    },
  }).then((result) => {
    if (result.value) {
      
      Swal.fire({
        title: 'Deleted!',
        text: 'Beneficiary deleted successfully',
        icon: 'success',
        confirmButtonText: 'Close',
        buttonsStyling: false,
        customClass: {
          confirmButton: 'btn btn-dark',
        },
        onClose: () => {
          location.reload();
        }
      })
    }
  })
}


function deleteBeneficiaryApi(beneficiaryId) {
  let deleteBeneficiaryUrl = `${ URL_ROOT }/apps/delete-beneficiary`;

  let beneficiaryData = {
    beneficiary_id: beneficiaryId
  }
$.ajax({
    url: deleteBeneficiaryUrl,
    type: 'POST',
    data: beneficiaryData,

     success: function (response) {

/*switch (response) {
      case false:
          showToast('error', 'Unable to delete beneficiary, contact help desk');
          break;

        case true:

          return response;
          break;
        default:
          break;
     }
    }});*/

}


})

}