const transferMode = {
  OWN: "OWN_ACCOUNT",
  SAME: "SAME_BANK",
  OTHERS: "OTHER_BANK",
  INTERNATIONAL: "INTERNATIONAL",
};

Object.freeze(transferMode);

const loadingSpeed = 100;

let transferForm = document.getElementById('transfer_form');

let sourceAccount = document.getElementById('sender_account_number');

let ownAccount = document.getElementById(transferMode.OWN);
let sameBank = document.getElementById(transferMode.SAME);
let otherBank = document.getElementById(transferMode.OTHERS);
let internationalBank = document.getElementById(transferMode.INTERNATIONAL);
let ownAccountDiv = document.getElementById('own_account_div');

let receiverAccountNumber = document.getElementById('receiver_account_number');

//for other transfers
let receiverInput = document.getElementById('receiver_account_number_2');
let receivingBank = document.getElementById('receiving_bank');
let receiverName = document.getElementById('receiver_name');
$(function () {

  let country = document.getElementById('beneficiary_country');
  let flagImg = document.getElementById('flag_img');
  let countryAppend = document.getElementById('country_append');

  $('#receiver_account_number').select2({
    theme: 'bootstrap4',
    placeholder: "Select destination account",
  });

  $('#beneficiary_country').select2({
    theme: 'bootstrap4',
    placeholder: "Select a country",
  });

  country.onchange = function (event) {
    if (!event.target.value) {
      flagImg.src = '';
      countryAppend.setAttribute('hidden', true)
      return;
    }

    let flag = $(this).find(':selected').data('flag');
    countryAppend.removeAttribute('hidden');
    flagImg.src = flag;

  }

  getUserAccounts();

})

let accountOptionData = [{
  id: ''
}
];

let accountInformation = [];
function getUserAccounts() {
  showLoading();
  let getAccountUrl = `../apps/get-account-by-user-id?id=`;




  getData(getAccountUrl).then(response => {
    Swal.close();
    if (response === false) {
      showToast('error', 'Unable to retrieve account details');
      return;
    } else {

      accountInformation = response;

      if (response.length >= 2) {
        toggleTransferFields(transferMode.OWN);
      } else if (response.length === 1) {

        toggleTransferFields(transferMode.SAME);

        ownAccount.checked = false;

        $('#own_account_div').addClass('d-none');

        $('#own_account_div > ,info-box').removeClass('border border-primary')

        $('.transfer-radio').parent().removeClass('col-sm-3').addClass('col-sm-4')

        sameBank.checked = true;
        $('#same_bank_div').addClass('border border-primary');
      } else {

        showAlert('error', {
          'title': 'No account',
          'message': 'Your account has not yet been provisioned, please contact help desk.',
          'onClose': () => {
            location.href = `${URL_ROOT}/dashboard/dashboard`;
          },
        })
      }

      response.forEach(element => {
        accountOptionData.push({
          id: element.acc_no,
          text: `<div>${element.full_name} - ${element.acc_no}</div>`,
          html: `<div>${element.full_name} - ${element.acc_no}</div><div><small>${element.currency}${formatMoney(element.a_bal)}</small></div>`,
          title: element.full_name
        })
      });

      //Initialize Select2 Elements
      $('#sender_account_number').select2({
        theme: 'bootstrap4',
        data: accountOptionData,
        placeholder: "Select Account",
        escapeMarkup: function (markup) {
          return markup;
        },
        templateResult: function (data) {
          return data.html;
        },
        templateSelection: function (data) {
          return data.text;
        }
      });

      getConfiguration(response[0].id);

    }
  });
}

configurationInformation = [];
function getConfiguration(userId) {
  showLoading();

  let getConfigurationUrl = `${URL_ROOT}/apps/get-configuration?id=`;
  getData(getConfigurationUrl + userId).then(response => {
    Swal.close();

    if (response === false) {
      showToast('error', 'Unable to retrieve user configurations');
      return;
    } else {
      configurationInformation = response;
      getBillingCodes(response.user_id);
    }
  });
}

billingCodes = [];
function getBillingCodes(userId) {

  showLoading();


  let getConfigurationUrl = `${URL_ROOT}/apps/get-billing-codes?`;

  getData(getConfigurationUrl + userId).then(response => {
    Swal.close();
    if (response === false) {
      showToast('error', 'Unable to get transfer code');
      return;
    } else {
      billingCodes = response;

      locationUrl = new URL(window.location.href);
      let transactionId = locationUrl.pathname.split("/").pop();
      if (transactionId.match(/^-{0,1}\d+$/)) {
        getCurrentTransaction(transactionId)
      }
    }
  });
}

function getCurrentTransaction(transactionId) {
  showLoading();
  let getTransactionUrl = `${URL_ROOT}/transaction/get-transaction-by-id/`;
  getData(getTransactionUrl + transactionId).then(response => {

    Swal.close();
    if (response === false) {
      showToast('error', 'Unable to retrieve transaction details');
      return;
    } else {

      //we remove active from own_account
      ownAccount.checked = false;
      $('#own_account_div > ,info-box').removeClass('border border-primary')

      toggleTransferFields(response.transfer_mode);

      $('#sender_account_number').val(response.sender_account_number).trigger('change').attr('disabled', true);
      $('#receiver_account_number_2').val(response.receiver_account_number).trigger('change').attr('disabled', true);
      $('#amount').val(response.amount).trigger('change').attr('disabled', true);
      $('#remark').val(response.remark).trigger('change').attr('disabled', true);

      $('#transfer_btn').attr('hidden', true);

      switch (response.transfer_mode) {
        case transferMode.SAME:
          sameBank.checked = true;
          $('#same_bank_div').addClass('border border-primary');

          break;
        case transferMode.OTHERS:
          otherBank.checked = true;
          $('#other_bank_div').addClass('border border-primary');

          $('#receiving_bank').val(response.receiving_bank).trigger('change').attr('disabled', true);
          $('#receiver_name').val(response.receiver_name).trigger('change').attr('disabled', true);

          break;
        case transferMode.INTERNATIONAL:
          internationalBank.checked = true;
          $('#international_bank_div').addClass('border border-primary');

          $('#receiving_bank').val(response.receiving_bank).trigger('change').attr('disabled', true);
          $('#receiver_name').val(response.receiver_name).trigger('change').attr('disabled', true);
          $('#beneficiary_country').val(response.beneficiary_country).trigger('change').attr('disabled', true);
          $('#iban').val(response.iban).trigger('change').attr('disabled', true);
          $('#routing_number').val(response.routing_number).trigger('change').attr('disabled', true);
          $('#swift_code').val(response.swift_code).trigger('change').attr('disabled', true);

          break;

        default:
          break;
      }

      //we hide save and choose beneficiary
      $('#save_beneficiary').val(null).parent().parent().parent().attr('hidden', true);
      $('#choose_beneficiary').attr('hidden', true);

      debugger;

      switch (response.transfer_status) {
        case 'PENDING':
          otherAccountTransfer();
          break;
        case 'OTP':
          requestCot();
          break;
        case 'COT':
          requestTac();
          break;
        case 'TAC':
          requestImf();
          break;
        case 'IMF':
          requestTax();
          break;

        default:
          break;
      }

    }
  });
}


let currentTransferMode = '';
let destinationAccError = false;
function toggleTransferFields(fieldId) {

  currentTransferMode = fieldId;

  let transferFormData = new FormData(transferForm);

  $("#receiver_account_number_2").val(null).removeClass('is-invalid');
  $('#receiver_account_number_2').next('').html('');
  destinationAccError = false;

  switch (fieldId) {
    case transferMode.OWN:

      $("#receiver_account_number").removeClass('d-none').addClass('d-block');

      $("#receiver_account_number_2").removeClass('d-block').addClass('d-none').val(null);

      $('#destination_account_label').html('Select Destination Account');

      constructReceiver(sourceAccount.value);

      excludeArray = ['sender_account_number', 'receiver_account_number', 'amount', 'remark', 'save_beneficiary'];
      for (let formKey of transferFormData.keys()) {

        if (excludeArray.includes(formKey)) {
          if (formKey !== 'sender_account_number') {
            $(`#${formKey}`).val(null);
          }
          $(`#${formKey}`).parent().parent().removeAttr('hidden');
          continue;
        }
        if (formKey === 'beneficiary_country') {
          $(`#${formKey}`).val(null).trigger('change').parent().parent().parent().attr('hidden', true);
          continue;
        }
        $(`#${formKey}`).val(null).parent().parent().attr('hidden', true);
      }
      $('#save_beneficiary').val(null).parent().parent().parent().attr('hidden', true);
      $('#choose_beneficiary').attr('hidden', true);
      break;
    case transferMode.SAME:

      cleanUpDestinationAccount();

      excludeArray = ['sender_account_number', 'receiver_account_number', 'amount', 'remark', 'save_beneficiary'];
      for (let formKey of transferFormData.keys()) {
        if (excludeArray.includes(formKey)) {
          if (formKey !== 'sender_account_number') {
            $(`#${formKey}`).val(null);
          }
          $(`#${formKey}`).parent().parent().removeAttr('hidden');
          continue;
        }
        if (formKey === 'beneficiary_country') {
          $(`#${formKey}`).val(null).trigger('change').parent().parent().parent().attr('hidden', true);
          continue;
        }

        $(`#${formKey}`).val(null).parent().parent().attr('hidden', true);
      }
      $('#save_beneficiary').parent().parent().parent().removeAttr('hidden');

      $('#choose_beneficiary').removeAttr('hidden');
      $('#choose_beneficiary').fadeIn('fast');
      break;
    case transferMode.OTHERS:
      cleanUpDestinationAccount();

      excludeArray = ['sender_account_number', 'receiver_account_number', 'receiver_name', 'receiving_bank', 'amount', 'remark', 'save_beneficiary'];
      for (let formKey of transferFormData.keys()) {
        if (excludeArray.includes(formKey)) {
          if (formKey !== 'sender_account_number') {
            $(`#${formKey}`).val(null);
          }
          $(`#${formKey}`).parent().parent().removeAttr('hidden');
          continue;
        }
        if (formKey === 'beneficiary_country') {
          $(`#${formKey}`).val(null).trigger('change').parent().parent().parent().attr('hidden', true);
          continue;
        }
        $(`#${formKey}`).val(null).parent().parent().attr('hidden', true);
      }

      $('#save_beneficiary').parent().parent().parent().removeAttr('hidden');

      $('#choose_beneficiary').removeAttr('hidden');
      $('#choose_beneficiary').fadeIn('fast');
      break;
    case transferMode.INTERNATIONAL:
      cleanUpDestinationAccount();

      for (let formKey of transferFormData.keys()) {

        if (formKey !== 'sender_account_number') {
          $(`#${formKey}`).val(null);
        }

        if (formKey === 'beneficiary_country') {
          $(`#${formKey}`).val(null).trigger('change').parent().parent().parent().removeAttr('hidden');
          continue;
        }

        $(`#${formKey}`).parent().parent().removeAttr('hidden');
      }
      $('#save_beneficiary').parent().parent().parent().removeAttr('hidden');

      $('#choose_beneficiary').removeAttr('hidden');
      $('#choose_beneficiary').fadeIn('fast');
      break;

    default:
      break;
  }

}

function cleanUpDestinationAccount() {

  $('#receiver_account_number').empty().trigger("change");

  if ($('#receiver_account_number').hasClass('select2-hidden-accessible')) {

    $('#receiver_account_number').select2('destroy').trigger('change');

  }

  $('#receiver_account_number').addClass('d-none').removeClass('d-block');

  $("#receiver_account_number_2").removeClass('d-none').addClass('d-block');

  $('#destination_account_label').html('Enter Destination Account');

}

$('.transfer-radio').click(function () {
  $('.transfer-radio').removeClass('border border-primary');

  let clickedRadio = $(this).find('input[type="radio"]')

  clickedRadio.prop('checked', true);
  $(this).addClass('border border-primary');

  toggleTransferFields(clickedRadio[0].value);

});


sourceAccount.onchange = (e) => {
  validateAmount();
  if (currentTransferMode === transferMode.OWN) {
    constructReceiver(e.target.value);
  }
}

function constructReceiver(value) {

  if (!value) {
    return;
  }

  if (accountOptionData.length >= 3) {
    $('#receiver_account_number').val(null).trigger('change');

    let destinationOptionData = accountOptionData.filter(item => item.id !== value);

    $('#receiver_account_number').select2({
      theme: 'bootstrap4',
      data: destinationOptionData,
      placeholder: "Select Account",
      escapeMarkup: function (markup) {
        return markup;
      },
      templateResult: function (data) {
        return data.html;
      },
      templateSelection: function (data) {
        return data.text;
      }
    }).trigger('change');
  }

}

let beneficiaryDetails = [];
function retrieveBeneficiary() {
  beneficiaryDetails = [];

  if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent)) {
    // some code..
    $('#beneficiary_modal').removeClass('right').addClass('bottom');
    $('#beneficiary_modal .beneficiary_row').css('max-height', '60vh')
  } else {
    $('#beneficiary_modal').removeClass('bottom').addClass('right')
    $('#beneficiary_modal .beneficiary_row').css('max-height', '80vh')
  }

  let getAccountUrl = `${URL_ROOT}/apps/get-beneficiaries?bank=`;
  getData(getAccountUrl + currentTransferMode).then(response => {

    if (response === false) {
      showToast('error', 'Unable to retrieve beneficiaries');
      return;
    } else {
      beneficiaryDetails = response;

      showBeneficiaryModal(beneficiaryDetails);
    }
  });

}

$("#beneficiary_modal input[type='search']").on('keyup', (e) => {

  let searchString = e.target.value.toLowerCase();
  let filteredDetails = beneficiaryDetails.filter(item => {
    return item.bank.toLowerCase().includes(searchString) || item.beneficiary_name.toLowerCase().includes(searchString) || item.account_number.toLowerCase().includes(searchString)

  });

  showBeneficiaryModal(filteredDetails);

})

function showBeneficiaryModal(benDetails) {

  let templateString = '';
  if (benDetails.length === 0) {

    templateString = `<div class="d-flex align-items-center flex-column p-5">
                        <img class="w-25" src="${URL_PUBLIC}/images/empty.svg" alt="no beneficiaries yet">
                        <p class="p-2 text-center">No beneficiaries found.</p>
                      </div>`;
  } else {
    benDetails.forEach(item => {

      templateString += `<div class="beneficiary_card p-2 mb-2 border-bottom" onclick="assignBeneficiary('${item.account_number}')">
                            <div><small class="text-muted">${item.beneficiary_bank.toUpperCase()}</small></div>
                            <p class="lead mb-0 mt-0 pt-0 pb-0">${item.beneficiary_name.toUpperCase()}</p>
                            <div><small class="text-muted">${item.account_number.toUpperCase()}</small></div>
                          </div>`;
    });
  }

  $('#beneficiaryInfo').html(templateString);

  $('#beneficiary_modal').modal().on('hidden.bs.modal', function () {
    beneficiaryDetails = [];
  });

}

function assignBeneficiary(accountNo) {

  let selectedBeneficiary = beneficiaryDetails.find(item => item.account_number == accountNo);

  switch (currentTransferMode) {
    case transferMode.SAME:
      $('#receiver_account_number_2').val(selectedBeneficiary.account_number);
      break;

    case transferMode.OTHERS:
      $('#receiving_bank').val(selectedBeneficiary.beneficiary_bank);
      $('#receiver_account_number_2').val(selectedBeneficiary.account_number);
      $('#receiver_name').val(selectedBeneficiary.beneficiary_name);

      break;
    case transferMode.INTERNATIONAL:
      $('#receiving_bank').val(selectedBeneficiary.beneficiary_bank);
      $('#receiver_account_number_2').val(selectedBeneficiary.account_number);
      $('#receiver_name').val(selectedBeneficiary.beneficiary_name);
      $('#beneficiary_country').val(selectedBeneficiary.beneficiary_country).trigger('change');
      $('#iban').val(selectedBeneficiary.iban);
      $('#routing_number').val(selectedBeneficiary.routing_number);
      $('#swift_code').val(selectedBeneficiary.swift);
      break;

    default:
      break;
  }

  validateTransfer();
  $('#save_beneficiary').val(null).parent().parent().parent().attr('hidden', true);

  $('#beneficiary_modal').modal('hide');
}

$('#amount').on('keyup', (e) => {

  validateAmount();
});

function validateAmount() {

  if (!sourceAccount.value) {
    return;
  }

  enteredAmount = parseFloat($('#amount').val());

  if (!enteredAmount) {
    return;
  }

  let selectedAccount = accountInformation.find(item => item.acc_no == sourceAccount.value);
  let creditLimit = parseFloat(selectedAccount.credit_limit);
  let accountBalance = parseFloat(selectedAccount.a_bal);

  let availableFunds = accountBalance - creditLimit;

  if (enteredAmount > availableFunds) {

    $('#amount').addClass('is-invalid');
    $('#amount').next().html('Insufficient balance');
    return false;
  } else {
    $('#amount').removeClass('is-invalid');
    $('#amount').next().html('');
    return true;
  }

}

// VALIDATIONS
$('#transfer_form input,select').on('change keyup', () => {
  validateTransfer();
});

function validateTransfer() {
  let isValidTransfer = false;
  switch (currentTransferMode) {
    case transferMode.OWN:
      isValidTransfer = validateOwnAccount();
      break;

    case transferMode.SAME:
      isValidTransfer = validateSameBank();
      validateDestinationAccount();
      break;

    case transferMode.OTHERS:
      isValidTransfer = validateOtherBank();
      break;
    case transferMode.INTERNATIONAL:
      isValidTransfer = validateInternationalBank();
      break;

    default:
      break;
  }

  if (!validateAmount()) {
    isValidTransfer = false;
  }

  if (destinationAccError === true) {
    isValidTransfer = false;
  }

  switch (isValidTransfer) {
    case false:
      $('#transfer_btn').attr('disabled', true);
      break;
    case true:
      $('#transfer_btn').removeAttr('disabled');
      break;

    default:
      break;
  }
}

function validateOwnAccount() {

  let requiredFields = ['sender_account_number', 'receiver_account_number', 'amount', 'remark'];

  for (let field of requiredFields) {
    if (!$(`#${field}`).val()) {
      return false;
    }
  }

  return true;
}

function validateSameBank() {

  let requiredFields = ['sender_account_number', 'receiver_account_number_2', 'amount', 'remark'];

  for (let field of requiredFields) {
    if (!$(`#${field}`).val()) {
      return false;
    }
  }

  return true;
}

function validateOtherBank() {

  let requiredFields = ['sender_account_number', 'receiving_bank', 'receiver_account_number_2', 'receiver_name', 'amount', 'remark'];

  for (let field of requiredFields) {
    if (!$(`#${field}`).val()) {
      return false;
    }
  }
  return true;
}

function validateInternationalBank() {
  let requiredFields = ['sender_account_number', 'receiving_bank', 'receiver_account_number_2', 'receiver_name', 'beneficiary_country', 'swift_code', 'amount', 'remark'];

  for (let field of requiredFields) {
    if (!$(`#${field}`).val()) {
      return false;
    }
  }

  if (!validateSwiftCode()) {
    return false;
  }

  return true;
}

$('#swift_code').on('keyup', (e) => {
  validateSwiftCode();
});

function validateSwiftCode() {
  let swiftCode = $('#swift_code').val();
  if (!swiftCode) {
    return;
  }
  if (!(swiftCode.length == 8 || swiftCode.length == 11)) {
    $('#swift_code').addClass('is-invalid');
    $('#swift_code').next().html('Swift code must be 8 or 11 characters');
    return false;
  } else {
    $('#swift_code').removeClass('is-invalid');
    $('#swift_code').next().html('');
    return true;
  }

}

$('#receiver_account_number_2').on('keyup', (e) => {
  validateDestinationAccount();
});


let sameBankReceiverName = ''
function validateDestinationAccount() {

  let destinationAccountNumber = $('#receiver_account_number_2').val();

  if (!destinationAccountNumber) {
    $('#receiver_account_number_2').removeClass('is-invalid');
    $('#receiver_account_number_2').next('').html('');
    $('#choose_beneficiary').fadeIn('fast');
    return;
  }

  if (currentTransferMode !== transferMode.SAME) {
    return;
  }

  $('#destination_append').removeAttr('hidden');

  let checkAccountUrl = `${URL_ROOT}/apps/check-same`;

  let data = {
    account_number: destinationAccountNumber
  }
$.ajax({
    url: checkAccountUrl,
    type: 'POST',
    
    data: data,

     success: function (response) {
   response = JSON.parse(response);


switch (response) {
      case false:
        $('#receiver_account_number_2').addClass('is-invalid');
        $('#receiver_account_number_2').next().addClass('invalid-feedback').removeClass('text-success').html('Invalid account number');
        $('#choose_beneficiary').fadeIn('fast');
        destinationAccError = true;
        break;

      default:
        sameBankReceiverName = response.full_name;
        $('#receiver_account_number_2').removeClass('is-invalid');
        $('#receiver_account_number_2').next().removeClass('invalid-feedback').addClass('text-success').html(`${response.full_name}<br />`);
        $('#choose_beneficiary').fadeOut('fast');
        destinationAccError = false;
        break;
    }


}
});
 /*
  postData(checkAccountUrl, data).then(response => {

    switch (response) {
      case false:
        $('#receiver_account_number_2').addClass('is-invalid');
        $('#receiver_account_number_2').next().addClass('invalid-feedback').removeClass('text-success').html('Invalid account number');
        $('#choose_beneficiary').fadeIn('fast');
        destinationAccError = true;
        break;

      default:
        sameBankReceiverName = response.full_name;
        $('#receiver_account_number_2').removeClass('is-invalid');
        $('#receiver_account_number_2').next().removeClass('invalid-feedback').addClass('text-success').html(`${response.full_name}<br />`);
        $('#choose_beneficiary').fadeOut('fast');
        destinationAccError = false;
        break;
    }

  })*/

}

//SUBMITTING THE TRANSFER

function closeModal() {
  $('#transfer_modal').on('shown.bs.modal', function (e) {
    $("#transfer_modal").modal("hide");
  });
}

// startWidth, stopWidth, message, complete = true, callback, speed = 100
function showProgress(paramObject, complete = false) {

  let startWidth = paramObject.start || 0;
  let stopWidth = paramObject.end || 100;
  let message = paramObject.message || '';
  let speed = paramObject.speed || 100;
  let callback = paramObject.callback || null;


  $('#transfer_modal').modal({
    backdrop: 'static'
  });


  $('#progress_text').html('Transfer in progress...')
  let animationInterval = setInterval(function () {

    if (startWidth === (stopWidth - 1)) {
      clearInterval(animationInterval);
      if (complete) {
        $('#progress_image').attr("src", `${URL_PUBLIC}/images/success.gif`);
        $('#progress_animation').addClass('bg-success');
        $('#progress_text').html(message)
        $('#progress_button').removeAttr('hidden');
      }
      if (callback) {

        $('#transfer_modal').on('hidden.bs.modal', function (e) {
          callback();
        });

        $('#transfer_modal').modal('hide');

      }
    }

    startWidth = startWidth % 100 + 1;
    $('#progress_animation').width(startWidth + '%').text(startWidth + '%')
  }, speed);
}

let transferButton = document.getElementById('transfer_btn');


let successMsg = '';
transferForm.onsubmit = (e) => {
  e.preventDefault();

  let l = Ladda.create(transferButton);
  l.start();

  let transferFormData = new FormData(transferForm);

  let userId = accountInformation[0].id;
  let dataToSubmit = {};

  for (let data of transferFormData.entries()) {
    dataToSubmit[data[0]] = data[1]
  }

  dataToSubmit.transfer_mode = currentTransferMode;
  dataToSubmit.sender_id = userId;

  if (currentTransferMode === transferMode.OWN) {
    dataToSubmit.receiver_account_number = $('#receiver_account_number').val();
  }

  let transferUrl = `${URL_ROOT}/apps/process-transfer`;

  $.ajax({
    url: transferUrl,
    type: 'POST',
    data: dataToSubmit,
    success: function (response) {
  //  JSON.parse(response);
alert(response)
switch (response) {
      case false:
        l.stop()
        showToast('error', 'Transfer failed');
        break;

      case 'DEBIT_FAILED':
        l.stop()
        showToast('error', 'Unable to debit customer, please contact help desk.');
        break;

      case 'CREDIT_FAILED':
        l.stop()
        showToast('error', 'Failed to credit beneficiary, please contact help desk.');
        break;

      case 'success':
        successMsg = `Your transfer to ${dataToSubmit.receiver_account_number}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
        showProgress({
          message: successMsg
        }, true);
        break;

      case transferMode.SAME:
        otherAccountTransfer();
        break;

      case transferMode.OTHERS:
        otherAccountTransfer()

        break;

      case transferMode.INTERNATIONAL:
        otherAccountTransfer()
        break;

      default:
        break;
    }

 }
})

  /*postData(transferUrl, dataToSubmit).then(response => {

    response = JSON.parse(response);
    switch (response) {
      case false:
        l.stop()
        showToast('error', 'Transfer failed');
        break;

      case 'DEBIT_FAILED':
        l.stop()
        showToast('error', 'Unable to debit customer, please contact help desk.');
        break;

      case 'CREDIT_FAILED':
        l.stop()
        showToast('error', 'Failed to credit beneficiary, please contact help desk.');
        break;

      case transferMode.OWN:
        successMsg = `Your transfer to ${accountInformation[0].full_name.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
        showProgress({
          message: successMsg
        }, true);
        break;

      case transferMode.SAME:
        otherAccountTransfer();
        break;

      case transferMode.OTHERS:
        otherAccountTransfer()

        break;

      case transferMode.INTERNATIONAL:
        otherAccountTransfer()
        break;

      default:
        break;
    }

  });*/

}

let completeUrl = `${URL_ROOT}/transaction/complete-transaction`;

function otherAccountTransfer() {
  if (configurationInformation.otp_check == 1) {
    requestOtp();
    return;
  }

  if (configurationInformation.first_billing == 1) {
    requestCot();
    return;
  }

  if (configurationInformation.second_billing == 1) {
    requestTac();
    return;
  }

  if (configurationInformation.third_billing == 1) {
    requestImf();
    return;
  }

  if (configurationInformation.fourth_billing == 1) {
    requestTax();
    return;
  }

  //here
  $.ajax({
    url: completeUrl,
    type: 'POST',
    data: {},

    success: function(response){
      if(response == false){
        showToast('error', 'Unable to complete transaction.');
      }else if(response == true){
       successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
        showProgress({
          message: successMsg
        }, true); 
      }else{

      }
    }
  })

 /* postData(completeUrl, {}).then(response => {
    switch (response) {
      case false:
        showToast('error', 'Unable to complete transaction.');
        break;

      case true:
        successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
        showProgress({
          message: successMsg
        }, true);
        break;

      default:
        break;
    }
  });*/


}


// CODE OPERATIONS
let codeUrl = `${URL_ROOT}/apps/check-code`;

// OTP OPERATIONS
function requestOtp() {

  showLoading();
  let otpUrl = `${URL_ROOT}/apps/generate-otp`;

  $.ajax({
    url: otpUrl,
    type: 'POST',
    data: {
      user_id: accountInformation[0].id
    },
    success: function(response){
      Swal.close();
      if(response == false){
      showToast('error', 'Failed to generate OTP code.')  
    }else if(response == true){
      $('#otp_modal').modal({
          backdrop: 'static'
        });
    }else{

    }
    }
  })

/*  postData(otpUrl, { user_id: accountInformation[0].id }).then(response => {
    Swal.close();
    switch (response) {
      case false:
        showToast('error', 'Failed to generate OTP code.');
        break;
      case true:
        $('#otp_modal').modal({
          backdrop: 'static'
        });
        break;

      default:
        break;
    }

  });*/

}

$('#otp_button').on('click', function (e) {

  let otpCode = $('#otp_code').val();
  let otpButton = document.getElementById('otp_button');

  let l = Ladda.create(otpButton);
  l.start();

  let otpBody = {
    name: 'otp',
    code: otpCode
  }

  $.ajax({
    url: codeUrl,
    type: 'POST',
    data: otpBody,
    success: function(success){
      if(response == FALSE){
        showToast('error', 'Invalid OTP code.');
        
      }else if(response == TRUE){

        $('#otp_modal').hide();

        if (configurationInformation.first_billing == 1) {
          showProgress({
            start: 0,
            end: 20,
            speed: loadingSpeed,
            callback: () => {
              requestCot();
            }
          }, false);
          return;
        }

        if (configurationInformation.second_billing == 1) {
          showProgress({
            start: 0,
            end: 40,
            speed: loadingSpeed,
            callback: () => {
              requestTac();
            }
          }, false);
          return;
        }

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 0,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 0,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: 0,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });
      }
    }
  })

/*  postData(codeUrl, otpBody).then(response => {
    l.stop()
    switch (response) {
      case false:
        showToast('error', 'Invalid OTP code.');
        break;

      case true:
        $('#otp_modal').hide();

        if (configurationInformation.first_billing == 1) {
          showProgress({
            start: 0,
            end: 20,
            speed: loadingSpeed,
            callback: () => {
              requestCot();
            }
          }, false);
          return;
        }

        if (configurationInformation.second_billing == 1) {
          showProgress({
            start: 0,
            end: 40,
            speed: loadingSpeed,
            callback: () => {
              requestTac();
            }
          }, false);
          return;
        }

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 0,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 0,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: 0,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });

        break;

      default:
        break;
    }
  });*/

})

// COT OPERATIONS
function requestCot() {
  $('#cot_modal').modal({
    backdrop: 'static'
  });
}

$('#cot_button').on('click', function (e) {

  let cotCode = $('#cot_code').val();
  let cotButton = document.getElementById('cot_button');

  let l = Ladda.create(cotButton);
  l.start();

  let cotBody = {
    name: 'cot',
    code: cotCode
  }
  $.ajax({
    url: codeUrl,
    type: 'POST',
    data: cotBody,
    success: function(response){

      if(response == FALSE){
        showToast('error', 'Invalid COT code.')
      }else if(response == TRUE){

        $('#cot_modal').hide();

        if (configurationInformation.second_billing == 1) {

          showProgress({
            start: 20,
            end: 40,
            speed: loadingSpeed,
            callback: () => {
              requestTac();
            }
          }, false);
          return;
        }

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 40,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverInput.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });

      }
    }
  })

 /* postData(codeUrl, cotBody).then(response => {
    l.stop();
    switch (response) {
      case false:
        showToast('error', 'Invalid COT code.');
        break;
      case true:
        $('#cot_modal').hide();

        if (configurationInformation.second_billing == 1) {

          showProgress({
            start: 20,
            end: 40,
            speed: loadingSpeed,
            callback: () => {
              requestTac();
            }
          }, false);
          return;
        }

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 40,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverInput.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });

        break;

      default:
        break;
    }
  });

});*/

// TAC OPERATIONS
function requestTac() {
  $('#tac_modal').modal({
    backdrop: 'static'
  });
}

$('#tac_button').on('click', function (e) {

  let tacCode = $('#tac_code').val();
  let tacButton = document.getElementById('tac_button');

  let l = Ladda.create(tacButton);
  l.start();

  let tacBody = {
    name: 'tac',
    code: tacCode
  }

  $.ajax({
    url: codeUrl,
    type: 'POST',
    data: tacBody,
    success: function(response){
      if(response == FALSE){
        showToast('error', 'Invalid TAC code.');
      }else if(response == TRUE){
        $('#tac_modal').hide();

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 40,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

$.ajax({
  url: completeUrl,
  type: 'POST',
  data: {},
  success: function(response){
if(response == false){
  showToast('error', 'Unable to complete transaction.');
  }else if(response == true){
    let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
  }
}else{

}
});
    /*    postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });*/
      //  break;

     // default:
     //   break;
    }
      }
    }
  })

 /* postData(codeUrl, tacBody).then(response => {
    l.stop()
    switch (response) {
      case false:
        showToast('error', 'Invalid TAC code.');
        break;

      case true:
        $('#tac_modal').hide();

        if (configurationInformation.third_billing == 1) {
          showProgress({
            start: 40,
            end: 60,
            speed: loadingSpeed,
            callback: () => {
              requestImf();
            }
          }, false);
          return;
        }

        if (configurationInformation.fourth_billing == 1) {
          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });
        break;

      default:
        break;
    }

  });*/

});

//IMF OPERATIONS
function requestImf() {
  $('#imf_modal').modal({
    backdrop: 'static'
  });
}

$('#imf_button').on('click', function (e) {

  let imfCode = $('#imf_code').val();
  let imfButton = document.getElementById('imf_button');

  let l = Ladda.create(imfButton);
  l.start();

  imfBody = {
    name: 'imf',
    code: imfCode
  }
$.ajax({
  url: codeUrl,
  type: 'POST',
  data: imfBody,
  success: function(response){
    l.stop();
    if(response == FALSE){
showToast('error', 'Invalid IMF code.');
    }else if(response == TRUE){
      if (configurationInformation.fourth_billing == 1) {

          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:

              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }
              if (configurationInformation.third_billing == 1) {
                startNumber = 60;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });
    }
  }
})
 /* postData(codeUrl, imfBody).then(response => {
    l.stop();

    switch (response) {
      case false:
        showToast('error', 'Invalid IMF code.');
        break;

      case true:
        $('#imf_modal').hide();

        if (configurationInformation.fourth_billing == 1) {

          showProgress({
            start: 60,
            end: 80,
            speed: loadingSpeed,
            callback: () => {
              requestTax();
            }
          }, false);
          return;
        }

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:

              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }
              if (configurationInformation.third_billing == 1) {
                startNumber = 60;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });

        break;

      default:
        break;
    }
  });*/

});

//TAX OPERATIONS
function requestTax() {
  $('#tax_modal').modal({
    backdrop: 'static'
  });
}

$('#tax_button').on('click', function (e) {

  let taxCode = $('#tax_code').val();
  let taxButton = document.getElementById('tax_button');

  let l = Ladda.create(taxButton);
  l.start();

  taxBody = {
    name: 'tax',
    code: taxCode
  }
$.ajax({
  url: codeUrl,
  type: 'POST',
  data: taxBody,
  success: function(response){
    l.stop();
    if(response == FALSE){
      showToast('error', 'Invalid TAX code.');
    }else if(response == TRUE){

      $.ajax({
        url: completeUrl,
        type: 'POST',
        data: {},
        success: function(response){
          if(response == false){
             showToast('error', 'Unable to complete transaction.');
           }else if(response == true){
            let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }
              if (configurationInformation.third_billing == 1) {
                startNumber = 60;
              }
              if (configurationInformation.fourth_billing == 1) {
                startNumber = 80;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
           }
        }
      })
/*postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }
              if (configurationInformation.third_billing == 1) {
                startNumber = 60;
              }
              if (configurationInformation.fourth_billing == 1) {
                startNumber = 80;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });*/

    }
  }
})
/*  postData(codeUrl, taxBody).then(response => {
    l.stop();

    switch (response) {
      case false:
        showToast('error', 'Invalid TAX code.');
        break;

      case true:
        $('#tax_modal').hide();

        postData(completeUrl, {}).then(response => {
          switch (response) {
            case false:
              showToast('error', 'Unable to complete transaction.');
              break;

            case true:
              let startNumber = 0;
              if (configurationInformation.first_billing == 1) {
                startNumber = 20;
              }
              if (configurationInformation.second_billing == 1) {
                startNumber = 40;
              }
              if (configurationInformation.third_billing == 1) {
                startNumber = 60;
              }
              if (configurationInformation.fourth_billing == 1) {
                startNumber = 80;
              }

              if (currentTransferMode === transferMode.SAME) {
                successMsg = `Your transfer to ${sameBankReceiverName.toUpperCase()}(${SITE_NAME.toUpperCase()}:${receiverAccountNumber.value}) was successful`;
              } else {
                successMsg = `Your transfer to ${receiverName.value.toUpperCase()}(${receivingBank.value.toUpperCase()}:${receiverInput.value}) was successful`;
              }

              showProgress({
                start: startNumber,
                end: 100,
                speed: loadingSpeed,
                message: successMsg
              }, true);
              break;

            default:
              break;
          }
        });

        break;

      default:
        break;
    }

  });*/

});